pub fn validate_from_bytes(
sidecar_json: &str,
media_bytes: &[u8],
) -> Result<ValidationResult>Expand description
Validate from sidecar JSON string and media bytes.
Useful when you have the content in memory rather than files.
pub fn validate_from_bytes(
sidecar_json: &str,
media_bytes: &[u8],
) -> Result<ValidationResult>Validate from sidecar JSON string and media bytes.
Useful when you have the content in memory rather than files.